@@ -1,4 +1,4 @@
-def count_delivery_price(price, weight):
+def count_delivery_price(price, weight, cart):
     if price < 10:
         return 5.0
     elif price < 20:
